Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(227)

Unified Diff: chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc

Issue 2622053004: ash: Restore previous show state after exiting fullscreen. (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc
diff --git a/chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc b/chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc
index d4397994bbdcfadeac6a7ef68bc635d0591d2ad7..abc6fb929eafbf966d5119a69f6b1bad7c1b5858 100644
--- a/chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc
+++ b/chrome/browser/ui/views/apps/chrome_native_app_window_views_aura_ash.cc
@@ -201,9 +201,9 @@ gfx::Rect ChromeNativeAppWindowViewsAuraAsh::GetRestoredBounds() const {
ui::WindowShowState
ChromeNativeAppWindowViewsAuraAsh::GetRestoredState() const {
// Use kRestoreShowStateKey in case a window is minimized/hidden.
ui::WindowShowState restore_state = widget()->GetNativeWindow()->GetProperty(
- aura::client::kRestoreShowStateKey);
+ aura::client::kPreMinimizedShowStateKey);
if (widget()->GetNativeWindow()->GetProperty(
ash::kRestoreBoundsOverrideKey)) {
@@ -224,10 +224,10 @@ ChromeNativeAppWindowViewsAuraAsh::GetRestoredState() const {
}
return ui::SHOW_STATE_FULLSCREEN;
}
- if (widget()->GetNativeWindow()->GetProperty(
- aura::client::kShowStateKey) == ui::SHOW_STATE_DOCKED ||
+ if (widget()->GetNativeWindow()->GetProperty(aura::client::kShowStateKey) ==
+ ui::SHOW_STATE_DOCKED ||
widget()->GetNativeWindow()->GetProperty(
- aura::client::kRestoreShowStateKey) == ui::SHOW_STATE_DOCKED) {
+ aura::client::kPreMinimizedShowStateKey) == ui::SHOW_STATE_DOCKED) {
return ui::SHOW_STATE_DOCKED;
}
}
@@ -201,9 +201,9 @@ gfx::Rect ChromeNativeAppWindowViewsAuraAsh::GetRestoredBounds() const {
ui::WindowShowState
ChromeNativeAppWindowViewsAuraAsh::GetRestoredState() const {
- // Use kRestoreShowStateKey in case a window is minimized/hidden.
+ // Use kPreMinimizedShowStateKey in case a window is minimized/hidden.
ui::WindowShowState restore_state = widget()->GetNativeWindow()->GetProperty(
« no previous file with comments | « chrome/browser/ui/views/apps/chrome_native_app_window_views_aura.cc ('k') | ui/aura/client/aura_constants.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698